@@ -32,22 +32,22 @@ SI <-function (mu.link ="log", sigma.link="log", nu.link="identity")
              sigma.dr = dstats$mu.eta, 
                 nu.dr = vstats$mu.eta,
                  dldm = function(y,mu,sigma,nu) {
-                         ty <- tofyS(y=y, mu=mu, sigma=sigma, nu=nu, what=1)
+                         ty <- gamlss.dist:::tofyS(y=y, mu=mu, sigma=sigma, nu=nu, what=1)
                        dldm <- (y-ty)/mu
                        dldm}, 
                d2ldm2 = function(y,mu,sigma,nu) {
-                        ty <- tofyS(y=y, mu=mu, sigma=sigma,nu=nu, what=1)
+                        ty <- gamlss.dist:::tofyS(y=y, mu=mu, sigma=sigma,nu=nu, what=1)
                       dldm <- (y-ty)/mu
                     d2ldm2 <- - dldm * dldm
                     d2ldm2
                                     },
                  dldd = function(y,mu,sigma,nu) {
-                        ty <- tofyS(y=y, mu=mu, sigma=sigma,nu=nu, what=1)
+                        ty <- gamlss.dist:::tofyS(y=y, mu=mu, sigma=sigma,nu=nu, what=1)
                      lbes2 <- log(besselK((1/sigma),nu+1))-log(besselK((1/sigma),nu))
                       dldd <- ((ty*(1+sigma*mu)/mu) - (sigma*y)-exp(lbes2))/(sigma^2)
                                  dldd},
                d2ldd2 = function(y,mu,sigma,nu){
-                       ty  <- tofyS(y=y, mu=mu, sigma=sigma,nu=nu, what=1)
+                       ty  <- gamlss.dist:::tofyS(y=y, mu=mu, sigma=sigma,nu=nu, what=1)
                      lbes2 <- log(besselK((1/sigma),nu+1))-log(besselK((1/sigma),nu))
                       dldd <- ((ty*(1+sigma*mu)/mu) - (sigma*y)-exp(lbes2))/(sigma^2)
                     d2ldd2 <- -dldd*dldd
@@ -55,7 +55,7 @@ SI <-function (mu.link ="log", sigma.link="log", nu.link="identity")
                                     },
               #d2ldmdd = function() 0,
               d2ldmdd = function(y,mu,sigma,nu) {
-                         ty <- tofyS(y=y, mu=mu, sigma=sigma, nu=nu, what=1)
+                         ty <- gamlss.dist:::tofyS(y=y, mu=mu, sigma=sigma, nu=nu, what=1)
                        dldm <- (y-ty)/mu
                       lbes2 <- log(besselK((1/sigma),nu+1))-log(besselK((1/sigma),nu))
                        dldd <- ((ty*(1+sigma*mu)/mu) - (sigma*y)-exp(lbes2))/(sigma^2)
@@ -63,7 +63,7 @@ SI <-function (mu.link ="log", sigma.link="log", nu.link="identity")
                     d2ldmdd
                                     }, 
               d2ldmdv = function(y,mu,sigma,nu) {
-                   ty <- tofyS(y=y, mu=mu, sigma=sigma, nu=nu, what=1)
+                   ty <- gamlss.dist:::tofyS(y=y, mu=mu, sigma=sigma, nu=nu, what=1)
                  dldm <- (y-ty)/mu
                  #calculates the dldv                 
                    nd <- gamlss.dist:::numeric.deriv(dSI(y, mu, sigma, nu, log=TRUE), "nu", delta=0.0001)
@@ -73,7 +73,7 @@ SI <-function (mu.link ="log", sigma.link="log", nu.link="identity")
               d2ldmdv
                                     }, 
               d2ldddv = function(y,mu,sigma,nu) {
-                  ty <- tofyS(y=y, mu=mu, sigma=sigma,nu=nu, what=1)
+                  ty <- gamlss.dist:::tofyS(y=y, mu=mu, sigma=sigma,nu=nu, what=1)
                lbes2 <- log(besselK((1/sigma),nu+1))-log(besselK((1/sigma),nu))
                 dldd <- ((ty*(1+sigma*mu)/mu) - (sigma*y)-exp(lbes2))/(sigma^2)
                 #calculates the dldv
@@ -102,7 +102,8 @@ SI <-function (mu.link ="log", sigma.link="log", nu.link="identity")
                   rqres(pfun="pSI", type="Discrete", ymin=0, y=y, mu=mu, sigma=sigma, nu=nu)
                                    ), #
             mu.initial = expression(mu<- y+0.5),
-         sigma.initial = expression( sigma<-rep((var(y)-mean(y))/(mean(y)^2), length(y))),
+         sigma.initial = expression(
+                      sigma <- rep( max( ((var(y)-mean(y))/(mean(y)^2)),0.1),length(y))),
             nu.initial = expression({  nu <- rep(-0.5,length(y)) }), 
               mu.valid = function(mu) all(mu > 0) , 
            sigma.valid = function(sigma)  all(sigma > 0), 
